<template>
    <div
        class="jumppage flex-center"
        :class="this.$route.query.type ? 'light-type' : ''"
    >
        <div v-if="this.$route.query.msg">
            <div v-if="this.$route.query.type" class="err-message">
                <i class="el-icon-warning"></i><br />
                {{ this.$route.query.msg }}
            </div>
            <el-tag v-else type="danger">{{ this.$route.query.msg }} </el-tag>
        </div>
        <el-card
            class="binding"
            v-if="this.$route.query.binding && !this.$route.query.type"
        >
            <div class="welcome-title">请输入改革报表填报系统使用人员账号</div>
            <el-form
                inline
                class="login-form"
                :model="login"
                :rules="rules"
                ref="login"
            >
                <el-form-item prop="account" label="账号">
                    <el-input
                        size="medium"
                        style="width: 100%"
                        clearable
                        prefix-icon="icon-account"
                        v-model="login.account"
                        placeholder="请输入账号"
                    ></el-input>
                </el-form-item>
                <el-form-item prop="password" label="密码">
                    <el-input
                        style="width: 100%"
                        show-password
                        clearable
                        prefix-icon="icon-password"
                        @keyup.enter.native="submitForm('login')"
                        @focus="inputGetFocus"
                        placeholder="请输入密码"
                        size="medium"
                        v-model="login.password"
                    ></el-input>
                </el-form-item>
                <el-button
                    size="medium"
                    type="primary"
                    @focus="inputGetFocus"
                    @click="submitForm('principal')"
                    class="login-btn"
                    :loading="loginLoading"
                    >登录</el-button
                >
            </el-form>
        </el-card>
        <div
            v-if="this.$route.query.binding && this.$route.query.type"
            class="mobile-form"
        >
            <div class="welcome-title mobile-title">
                请输入改革报表填报系统使用人员账号
            </div>
            <van-form @submit="onSubmit">
                <van-field
                    v-model="login.account"
                    name="用户名"
                    label="用户名"
                    placeholder="用户名"
                    :rules="[{required: true, message: '请填写用户名'}]"
                />
                <van-field
                    v-model="login.password"
                    type="password"
                    name="密码"
                    label="密码"
                    placeholder="密码"
                    :rules="[{required: true, message: '请填写密码'}]"
                />
                <div style="margin: 16px">
                    <van-button round block type="info" native-type="submit"
                        >提交</van-button
                    >
                </div>
            </van-form>
        </div>
    </div>
</template>

<script>
import {Loading} from 'element-ui'
export default {
    name: 'jumping',
    data() {
        var checkAccount = (rule, value, callback) => {
            if (!value) {
                return callback(new Error('请输入账号'))
            }
            if (/^[a-zA-Z0-9_-]{2,20}$/.test(value)) {
                return callback()
            } else {
                return callback(new Error('账号格式不符合规范'))
            }
        }
        return {
            loading: null,
            loginLoading: false,
            login: {
                account: '',
                password: '',
                // remberPwd: 0,
            },
            rules: {
                account: [
                    {validator: checkAccount, trigger: 'blur'},
                    {required: true, message: '请输入账号', trigger: 'blur'},
                ],
                password: [
                    {required: true, message: '请输入密码', trigger: 'blur'},
                ],
            },
        }
    },
    mounted() {
        if (this.$route.query.auth_code) {
            this.openFullScreen()
        }
    },
    watch: {
        $route: {
            handler(to, from) {
                if (this.$route.query.msg || this.$route.query.binding) {
                    this.showMsg()
                }
            },
            deep: true, // 深度监听
            immediate: true, // 第一次初始化渲染就可以监听到
        },
    },
    methods: {
        showMsg() {
            if (this.loading) this.loading.close()
        },
        inputGetFocus() {
            this.responseError = ''
        },
        openFullScreen() {
            this.loading = Loading.service({
                lock: true,
                text: '改革报表加载中......',
                spinner: 'el-icon-loading',
                background: this.$route.query.type
                    ? 'rgba(0, 0, 0, 0.1)'
                    : 'rgba(0, 0, 0, 0.6)',
            })
        },
        onSubmit(values) {
            this.handleLogin()
        },
        submitForm() {
            this.$refs.login.validate((valid) => {
                if (valid) {
                    this.inputGetFocus()
                    this.handleLogin()
                } else {
                    return false
                }
            })
        },
        handleLogin() {
            this.loginLoading = true
            if (
                !this.$route.params ||
                !this.$route.params.account ||
                !this.$route.params.openid
            ) {
                this.$message.warning('愉快政验证已失效，请重新验证！')
                return
            }
            let data = {
                loginData: this.login,
                ykzData: {
                    ykzAccount: this.$route.params.account,
                    ykzAccountId: this.$route.params.openid,
                },
            }
            this.$store
                .dispatch('login/bindingYKZ', data)
                .then((user) => {
                    console.log(user)
                    if (user.loginStatus && user.loginStatus == true) {
                        //获取前台页面
                        this.$store.dispatch('login/getAllDict')
                        if (this.$route.query.type) {
                            this.$router.push({
                                path: `/MajorProjectsMobile`,
                            })
                        } else {
                            //获取前台所有菜单
                            this.$store
                                .dispatch('menu/actionFrontMenus')
                                .then((res) => {
                                    let dataArr =
                                        res &&
                                        res.filter(
                                            (item) => item.alias === 'bigScreen'
                                        )
                                    // 如果用户有大屏菜单进去大屏页面
                                    if (dataArr && dataArr.length !== 0) {
                                        if (dataArr[0].children.length !== 0) {
                                            this.$router.push({
                                                path: `/${dataArr[0].children[0].alias}`,
                                            })
                                        }
                                    } else {
                                        // 如果用户没有大屏菜单 则根据第一角色查菜单
                                        this.getRoleMenus()
                                    }
                                    this.loginLoading = false
                                })
                        }
                    } else if (user.loginStatus == false) {
                        console.log(user)
                        let msg = user.message
                            ? user.message
                            : '登录失败，请重新验证！'
                        this.$message.warning(msg)
                    }
                })
                .catch((msg) => {
                    console.log(msg)
                    this.$message.warning(msg)
                    this.loginLoading = false
                })
        },
    },
    findFirstChild(meuns) {
        if (meuns[0].children && meuns[0].children.length) {
            return this.findFirstChild(meuns[0].children)
        } else {
            return meuns[0].alias
        }
    },
    getRoleMenus() {
        let UserDetail = JSON.parse(sessionStorage.getItem('currentUserDetail'))
        let defaultRoleCode = UserDetail.roleList[0].roleCode
        sessionStorage.setItem('currentRoleCode', defaultRoleCode)
        this.$store
            .dispatch('menu/actionsRoleMenu', defaultRoleCode)
            .then((res) => {
                let dataMenus =
                    res && res.filter((item) => item.alias === 'normal')
                if (dataMenus && dataMenus.length !== 0) {
                    let alias = findFirstChild(dataMenus)
                    this.$router.push({
                        path: `/platLayout/${alias}`,
                    })
                }
            })
    },
    beforeDestroy() {
        if (this.loading) this.loading.close()
    },
}
</script>

<style lang="scss" scoped>
.jumppage{
    width:100%;
    height: 100%;
    background: #0c1f3f;
}
.jumppage.light-type{
    background: #f2f2f2;;
}
.flex-center{
    display: flex;
    justify-content: center;
    align-items: center;
}
.binding{
    width: 460px;
}
.login-form{
    width: 400px;
    margin: 20px auto;
    text-align: center;
}
.welcome-title {
    color: #12bae7;
    margin: 20px 0 50px 0;
    font-size: 20px;
    font-weight: bold;
    letter-spacing: 2px;
    text-align: center;
    font-family: Roboto, Microsoft YaHei, Sans-serif;
}
.welcome-title.mobile-title{
     margin-bottom: 2rem;
     font-size:16PX;

}
.login-btn {
    width: 300px;
    margin-top: 20px;
    border: 1px solid #2182f7;
    background-color: #2182f7;
}
.err-message{
    color: #1E1E1E;
    text-align: center;
    i{
        font-size: 20PX;
        color: #E84646;
        margin-bottom: 10PX;
    }
}
.mobile-form{
    background-color: #fff;
    padding: 4rem 2rem 2rem 2rem;
    border-radius: 10PX;
}
</style>